@@ -13,18 +13,15 @@ log    <-  c("FALSE")
 
 i      <- 1
 
-net  <- GenerateNet(N = 20, m = 50,prob_m = prob_m, 
+net  <- generate_net(N = 20, m = 50,prob_m = prob_m, 
                     increase = inc, log = log,
                     mode = i, shape = 10, rate = 10,alpha = 0.5)
 
-net_stats <- GetStatistics(net$graph,deg_threshold = 0, 
+net_stats <- get_statistics(net$graph,deg_threshold = 0, 
                            net_type = "directed",
-                           Binning = TRUE, G = 50) 
+                           binning = TRUE, g = 50) 
 
-result <- JointEstimate(raw_net = net$graph, 
+result <- joint_estimate(raw_net = net$graph, 
                         net_stat = net_stats, 
-                        stop.cond = 10^-3,
-                         print.out = TRUE)
+                        stop_cond = 10^-3)
 
-
-#print(result)
