@@ -9,20 +9,15 @@ if (FALSE) {
   
 
     
-    net  <- GenerateNet(N = 1000, m = 50,prob_m = prob_m, num_seed = 100, multiple_node = 100,
+    net  <- generate_net(N = 1000, m = 50,prob_m = prob_m, num_seed = 100, multiple_node = 100,
                         increase = inc, log = log,
                         mode = 1, shape = 100, rate = 100,alpha = 0.5)
     
-    net_stats <- GetStatistics(net$graph,deg_threshold = 0, 
+    net_stats <- get_statistics(net$graph,deg_threshold = 0, 
                                net_type = "directed",
-                               Binning = TRUE, G = 50) 
-    
-    result <- PAFit_new(net_stats,r = 1, s = 100, mode_f = "Log_linear")
-    
-    plot(result,net_stats)
-    
-    plot(result,net_stats,true_f = net$fitness, plot = "true_f", high_deg_f = 1)
+                               binning = TRUE, g = 50) 
     
+  
     
     T <- max(net_stats$appear_time)
     var_array <- rep(0,T)
